@@ -42,7 +42,7 @@ def pytest_runtest_makereport(item, call):
 @pytest.fixture
 def test_obj(base_url, browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag,
              test_run_id, remote_project_name, remote_build_name, testname, reportportal_service, interactivemode_flag,
-             test_env, screenshot_option, xlsx_config, product, breakable, capture):
+             test_env, screenshot_option, xlsx_config, product, breakable, capture, wdm):
     "Return an instance of Base Page that knows about the third party integrations"
     try:
 
@@ -55,6 +55,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         test_obj = Zero_Page(base_url="http://", product=product)
         test_obj.test_env = test_env
         test_obj.breakable = breakable
+        test_obj.wdm = wdm
         test_obj.screenshot = screenshot_option
         test_obj.set_calling_module(testname)
         test_obj.product = product
@@ -62,7 +63,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         test_obj.xlsx_config = xlsx_config
         # Setup and register a driver
         test_obj.register_driver(remote_flag, os_name, os_version, browser, browser_version, remote_project_name,
-                                 remote_build_name)
+                                 remote_build_name, wdm)
         test_obj.capture = capture
 
         # Setup TestRail reporting
@@ -111,7 +112,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
 @pytest.fixture
 def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package, app_activity, remote_flag, device_flag, testname,
                     testrail_flag, tesults_flag, test_run_id, app_name, app_path, appium_version, test_env, reportportal_service,
-                    interactivemode_flag, product, xlsx_config, screenshot_option, no_reset_flag):
+                    interactivemode_flag, product, xlsx_config, screenshot_option, no_reset_flag, wdm, breakable):
     """Return an instance of Base Page that knows about the third party integrations
     Need to install appium with npm first: npm install -g appium"""
     try:
@@ -123,8 +124,9 @@ def test_mobile_obj(mobile_os_name, mobile_os_version, device_name, app_package,
         test_mobile_obj = Mobile_Zero_Page(product=product)
         test_mobile_obj.test_env = test_env
         test_mobile_obj.screenshot = screenshot_option
+        test_mobile_obj.breakable = breakable
+        test_mobile_obj.wdm = wdm
         test_mobile_obj.set_calling_module(testname)
-
         test_mobile_obj.xlsx_config = xlsx_config
         # Setup and register a driver
         test_mobile_obj.register_driver(mobile_os_name, mobile_os_version, device_name, app_package, app_activity,
@@ -209,6 +211,19 @@ def breakable(request):
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
 
+@pytest.fixture
+def wdm(request):
+    "pytest fixture for app activity"
+    try:
+        if request.config.getoption("--wdm") == 'Y' or 'N':
+            return request.config.getoption("--wdm")
+        else:
+            raise Exception("Invalid value for --wdm --- please enter Y or N")
+
+    except Exception as e:
+        print("Exception when trying to run test: %s" % __file__)
+        print("Python says:%s" % str(e))
+
 
 @pytest.fixture
 def cases(request, product, testID):
@@ -418,11 +433,7 @@ def pytest_addoption(parser):
         parser.addoption("--case",
                          dest="case",
                          default="-1",
-                         help="Number of case which need to run in Excel config. Do no use this option for running all cases. Input number > 0")
-        parser.addoption("--caseid",
-                         dest="caseid",
-                         default='',
-                         help="Case ID which need to run in Excel config. Do no use this option for running all cases. Only support 1 case")
+                         help="only for -loop mode usage, Number of case which need to run in Excel config. Do no use this option for running all cases. Input number > 0")
         parser.addoption("--bdd_flag",
                          dest="bdd_flag",
                          default='N',
@@ -431,10 +442,11 @@ def pytest_addoption(parser):
                          dest="breakable",
                          default='Y',
                          help="Determine when failure happen, the flow will break or not: Y or N")
-        # parser.addoption("--bdd_flag",
-        #                  dest="bdd_flag",
-        #                  default="N",
-        #                  help="Determine if the run is in BDD: Y or N")
+        parser.addoption("--wdm",
+                         dest="wdm",
+                         default='N',
+                         help="Determine user want to use Web driver Manager or not: Y or N")
+
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
